@@ -132,24 +132,29 @@
 #endif
 
 #if (defined(NV_MACINTOSH) && !(defined(__i386__) || defined(__x86_64__)))  || defined(__PPC__) || defined(__ppc)
-#if defined(__powerpc64__) && defined(__LITTLE_ENDIAN__)
-#   ifndef NVCPU_PPC64LE
-#   define NVCPU_PPC64LE           /* PPC 64-bit little endian */
-#   endif
-#else
-#   ifndef NVCPU_PPC
-#   define NVCPU_PPC               /* any non-PPC64LE PowerPC architecture */
-#   endif
-#   ifndef NV_BIG_ENDIAN
-#   define NV_BIG_ENDIAN
-#   endif
-#endif
+#    if defined(__powerpc64__) && defined(__LITTLE_ENDIAN__)
+#       ifndef NVCPU_PPC64LE
+#           define NVCPU_PPC64LE           /* PPC 64-bit little endian */
+#       endif
+#    else
+#       ifndef NVCPU_PPC
+#           define NVCPU_PPC               /* any non-PPC64LE PowerPC architecture */
+#       endif
+#       ifndef NV_BIG_ENDIAN
+#           define NV_BIG_ENDIAN
+#       endif
+#    endif
+#    define NVCPU_FAMILY_PPC
 #endif
 
 #if defined(__x86_64) || defined(AMD64) || defined(_M_AMD64)
 #    define NVCPU_X86_64           /* any x86-64 for any opsys */
 #endif
 
+#if defined(NVCPU_X86) || defined(NVCPU_X86_64)
+#    define NVCPU_FAMILY_X86
+#endif
+
 #if defined(__arm__) || defined(_M_ARM)
 /*
  * 32-bit instruction set on, e.g., ARMv7 or AArch32 execution state
@@ -324,6 +329,11 @@
 #else
 #define NVCPU_IS_X86_64 0
 #endif
+#if defined(NVCPU_FAMILY_X86)
+#define NVCPU_IS_FAMILY_X86 1
+#else
+#define NVCPU_IS_FAMILY_X86 0
+#endif
 #if defined(NVCPU_PPC)
 #define NVCPU_IS_PPC 1
 #else
@@ -334,6 +344,11 @@
 #else
 #define NVCPU_IS_PPC64LE 0
 #endif
+#if defined(NVCPU_FAMILY_PPC)
+#define NVCPU_IS_FAMILY_PPC 1
+#else
+#define NVCPU_IS_FAMILY_PPC 0
+#endif
 #if defined(NVCPU_ARM)
 #define NVCPU_IS_ARM 1
 #else
