@@ -120,6 +120,16 @@ NvlStatus NVLINK_API_CALL ibmnpu_lib_register_device
  */
 NvlStatus NVLINK_API_CALL ibmnpu_lib_service_device(nvlink_pci_info *info);
 
+/*
+ * @Brief : Notifies the core to avoid MMIO for the device with the given info.
+ *
+ * @Description :
+ *
+ * @param[in] info          reference to the pci info of the device to abort
+ *
+ * @returns                 void
+ */
+void NVLINK_API_CALL ibmnpu_lib_stop_device_mmio(nvlink_pci_info *info);
 
 /*
  * Initializes ibmnpu library, preparing the driver to register
@@ -159,6 +169,11 @@ NvlStatus NVLINK_API_CALL ibmnpu_lib_initialize_device_interrupt
  */
 NvlStatus NVLINK_API_CALL ibmnpu_lib_unload(void);
 
+/*
+ * Disables the pci bus for the given device.
+ */
+NvlStatus NVLINK_API_CALL ibmnpu_lib_shutdown_device_pci_bus(void *handle);
+
 /*
  * Unmaps the previously mapped base address registers from cpu memory.
  */
