@@ -303,7 +303,7 @@ typedef struct nv_mmap_context_s
     NvP64 addr;
     NvU64 size;
     NvU32 process_id;
-    NvU32 thread_id;
+    NvU64 thread_id;
     void *file;
     void *os_priv;
     struct nv_mmap_context_s *next;
@@ -353,6 +353,7 @@ typedef struct
 
     nv_kern_mapping_t *kern_mappings;
 
+    void *mmap_mutex;
     nv_mmap_context_t *mmap_contexts;
  
     /* DMA addressable range of the device */
@@ -416,7 +417,8 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 
 #define NV_PRIMARY_VGA(nv)      ((nv)->primary_vga)
 
-#define NV_IS_GVI_DEVICE(nv) ((nv)->flags & NV_FLAG_GVI)
+#define NV_IS_GVI_DEVICE(nv)    ((nv)->flags & NV_FLAG_GVI)
+#define NV_IS_CTL_DEVICE(nv)    ((nv)->flags & NV_FLAG_CONTROL)
 
 /*                                                                                    
  * The ACPI specification defines IDs for various ACPI video                          
@@ -586,7 +588,8 @@ void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, N
 NV_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
 NV_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
-NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
+NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, NvU32, void *, NvU64, void *, void **);
+void       NV_API_CALL  nv_destroy_user_mapping_context (nv_state_t *, void *, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -779,8 +782,8 @@ void       NV_API_CALL rm_gpu_ops_p2p_object_destroy(nvidia_stack_t *, nvgpuSess
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_big_page_size(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvU32 *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_external_alloc_ptes(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvHandle, NvU64, NvU64, nvgpuExternalMappingInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, nvgpuChannelInstanceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, nvgpuChannelResourceBindParams_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU32, NvU32, nvgpuChannelResourceBindParams_t);
 void       NV_API_CALL rm_gpu_ops_release_channel(nvidia_stack_t *, NvP64);
 void       NV_API_CALL rm_gpu_ops_release_channel_resources(nvidia_stack_t *, NvP64*, NvU32);
 void       NV_API_CALL rm_gpu_ops_stop_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvBool);
