@@ -930,6 +930,10 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     nv_state_t *nv,
     NvU64 address,
     NvU64 size,
+    NvU32 prot,
+    void *pAllocPriv,
+    NvU64 pageIndex,
+    void *file,
     void **ppPrivate
 )
 {
@@ -937,6 +941,14 @@ NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     return NV_OK;
 }
 
+void NV_API_CALL nv_destroy_user_mapping_context(
+    nv_state_t *nv,
+    void *pFile,
+    void *pPrivate
+)
+{
+}
+
 NV_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
